@@ -93,7 +93,7 @@ static int afs_encode_fh(struct dentry *de, __u32 *fh, int *max_len,
 		if (*max_len < 5) {
 		    return 255;
 		}
-		/* fall through */
+		AFS_FALLTHROUGH;
 
 	    case VN_TYPE_CELL:
 	    case VN_TYPE_ALIAS:
@@ -349,7 +349,7 @@ redo:
      */
     while ((adp->f.states & CStatd)
 	   && (tdc->dflags & DFFetching)
-	   && hsame(adp->f.m.DataVersion, tdc->f.versionNo)) {
+	   && afs_IsDCacheFresh(tdc, adp)) {
 	ReleaseReadLock(&tdc->lock);
 	ReleaseSharedLock(&adp->lock);
 	afs_osi_Sleep(&tdc->validPos);
@@ -357,7 +357,7 @@ redo:
 	ObtainReadLock(&tdc->lock);
     }
     if (!(adp->f.states & CStatd)
-	|| !hsame(adp->f.m.DataVersion, tdc->f.versionNo)) {
+	|| !afs_IsDCacheFresh(tdc, adp)) {
 	ReleaseReadLock(&tdc->lock);
 	ReleaseSharedLock(&adp->lock);
 	afs_PutDCache(tdc);
@@ -408,7 +408,7 @@ static int UnEvalFakeStat(struct vrequest *areq, struct vcache **vcpp)
     if (!afs_fakestat_enable)
 	return 0;
 
-    if (*vcpp == afs_globalVp || vType(*vcpp) != VDIR || (*vcpp)->mvstat != 2)
+    if (*vcpp == afs_globalVp || vType(*vcpp) != VDIR || (*vcpp)->mvstat != AFS_MVSTAT_ROOT)
 	return 0;
 
     /* Figure out what FID to look for */
@@ -505,7 +505,7 @@ static struct dentry *get_dentry_from_fid(cred_t *credp, struct VenusFid *afid)
      * at parentVnode on directories, except for VIOCGETVCXSTATUS.
      * So, if this fails, we don't really care very much.
      */
-    if (vType(vcp) == VDIR && vcp->mvstat != 2 && !vcp->f.parent.vnode)
+    if (vType(vcp) == VDIR && vcp->mvstat != AFS_MVSTAT_ROOT && !vcp->f.parent.vnode)
 	update_dir_parent(treq, vcp);
 
     /*
@@ -520,7 +520,7 @@ static struct dentry *get_dentry_from_fid(cred_t *credp, struct VenusFid *afid)
 	       code);
 #endif
 	afs_PutVCache(vcp);
-	code = afs_CheckCode(code, treq, 101);
+	code = afs_CheckCode(code, treq, 103);
 	afs_DestroyReq(treq);
 	afs_DestroyAttr(vattr);
 	return ERR_PTR(-code);
@@ -642,7 +642,7 @@ static int afs_export_get_name(struct dentry *parent, char *name,
     }
 
     /* Figure out what FID to look for */
-    if (vcp->mvstat == 2) { /* volume root */
+    if (vcp->mvstat == AFS_MVSTAT_ROOT) { /* volume root */
 	tvp = afs_GetVolume(&vcp->f.fid, 0, READ_LOCK);
 	if (!tvp) {
 #ifdef OSI_EXPORT_DEBUG
@@ -770,7 +770,7 @@ redo:
      */
     while ((vcp->f.states & CStatd)
 	   && (tdc->dflags & DFFetching)
-	   && hsame(vcp->f.m.DataVersion, tdc->f.versionNo)) {
+	   && afs_IsDCacheFresh(tdc, vcp)) {
 	ReleaseReadLock(&tdc->lock);
 	ReleaseReadLock(&vcp->lock);
 	afs_osi_Sleep(&tdc->validPos);
@@ -778,7 +778,7 @@ redo:
 	ObtainReadLock(&tdc->lock);
     }
     if (!(vcp->f.states & CStatd)
-	|| !hsame(vcp->f.m.DataVersion, tdc->f.versionNo)) {
+	|| !afs_IsDCacheFresh(tdc, vcp)) {
 	ReleaseReadLock(&tdc->lock);
 	ReleaseReadLock(&vcp->lock);
 	afs_PutDCache(tdc);
@@ -869,11 +869,11 @@ static struct dentry *afs_export_get_parent(struct dentry *child)
 	/* a mount point in the dynmount directory */
 	afs_GetDynrootMountFid(&tfid);
 
-    } else if (vcp->mvstat == 2) {
+    } else if (vcp->mvstat == AFS_MVSTAT_ROOT) {
 	/* volume root */
 	ObtainReadLock(&vcp->lock);
-	if (vcp->mvid && vcp->mvid->Fid.Volume) {
-	    tfid = *vcp->mvid;
+	if (vcp->mvid.parent && vcp->mvid.parent->Fid.Volume) {
+	    tfid = *vcp->mvid.parent;
 	    ReleaseReadLock(&vcp->lock);
 	} else {
 	    ReleaseReadLock(&vcp->lock);
@@ -898,7 +898,7 @@ static struct dentry *afs_export_get_parent(struct dentry *child)
 
     } else {
 	/* any other vnode */
-	if (vType(vcp) == VDIR && !vcp->f.parent.vnode && vcp->mvstat != 1) {
+	if (vType(vcp) == VDIR && !vcp->f.parent.vnode && vcp->mvstat != AFS_MVSTAT_MTPT) {
 	    code = afs_CreateReq(&treq, credp);
 	    if (code) {
 #ifdef OSI_EXPORT_DEBUG
