@@ -32,7 +32,7 @@
 #endif
 #include <linux/pagemap.h>
 #include <linux/writeback.h>
-#if defined(HAVE_LINUX_LRU_CACHE_ADD_FILE)
+#if defined(HAVE_LINUX_FOLIO_ADD_LRU) || defined(HAVE_LINUX_LRU_CACHE_ADD_FILE)
 # include <linux/swap.h>
 #else
 # include <linux/pagevec.h>
@@ -78,7 +78,8 @@ extern struct vcache *afs_globalVp;
 
 /* Handle interfacing with Linux's pagevec/lru facilities */
 
-#if defined(HAVE_LINUX_LRU_CACHE_ADD_FILE) || defined(HAVE_LINUX_LRU_CACHE_ADD)
+#if defined(HAVE_LINUX_FOLIO_ADD_LRU) || \
+    defined(HAVE_LINUX_LRU_CACHE_ADD_FILE) || defined(HAVE_LINUX_LRU_CACHE_ADD)
 
 /*
  * Linux's lru_cache_add_file provides a simplified LRU interface without
@@ -97,7 +98,10 @@ afs_lru_cache_init(struct afs_lru_pages *alrupages)
 static inline void
 afs_lru_cache_add(struct afs_lru_pages *alrupages, struct page *page)
 {
-# if defined(HAVE_LINUX_LRU_CACHE_ADD)
+# if defined(HAVE_LINUX_FOLIO_ADD_LRU)
+    struct folio *folio = page_folio(page);
+    folio_add_lru(folio);
+# elif defined(HAVE_LINUX_LRU_CACHE_ADD)
     lru_cache_add(page);
 # elif defined(HAVE_LINUX_LRU_CACHE_ADD_FILE)
     lru_cache_add_file(page);
@@ -990,16 +994,7 @@ canonical_dentry(struct inode *ip)
 
     afs_d_alias_lock(ip);
 
-#if defined(D_ALIAS_IS_HLIST)
-# if defined(HLIST_ITERATOR_NO_NODE)
-    hlist_for_each_entry(cur, &ip->i_dentry, d_alias) {
-# else
-    hlist_for_each_entry(cur, p, &ip->i_dentry, d_alias) {
-# endif
-#else
-    list_for_each_entry_reverse(cur, &ip->i_dentry, d_alias) {
-#endif
-
+    afs_d_alias_foreach_reverse(cur, ip, p) {
 	if (!vcp->target_link || cur == vcp->target_link) {
 	    ret = cur;
 	    break;
@@ -1142,7 +1137,10 @@ vattr2inode(struct inode *ip, struct vattr *vp)
  * Linux version of setattr call. What to change is in the iattr struct.
  * We need to set bits in both the Linux inode as well as the vcache.
  */
-#if defined(IOP_TAKES_USER_NAMESPACE)
+#if defined(IOP_TAKES_MNT_IDMAP)
+static int
+afs_notify_change(struct mnt_idmap *idmap, struct dentry *dp, struct iattr *iattrp)
+#elif defined(IOP_TAKES_USER_NAMESPACE)
 static int
 afs_notify_change(struct user_namespace *mnt_userns, struct dentry *dp, struct iattr *iattrp)
 #else
@@ -1176,7 +1174,18 @@ out:
     return afs_convert_code(code);
 }
 
-#if defined(IOP_TAKES_USER_NAMESPACE)
+#if defined(IOP_TAKES_MNT_IDMAP)
+static int
+afs_linux_getattr(struct mnt_idmap *idmap, const struct path *path, struct kstat *stat,
+		  u32 request_mask, unsigned int sync_mode)
+{
+	int err = afs_linux_revalidate(path->dentry);
+	if (!err) {
+		generic_fillattr(afs_mnt_idmap, path->dentry->d_inode, stat);
+	}
+	return err;
+}
+#elif defined(IOP_TAKES_USER_NAMESPACE)
 static int
 afs_linux_getattr(struct user_namespace *mnt_userns, const struct path *path, struct kstat *stat,
 		  u32 request_mask, unsigned int sync_mode)
@@ -1657,7 +1666,11 @@ struct dentry_operations afs_dentry_operations = {
  * name is in kernel space at this point.
  */
 
-#if defined(IOP_TAKES_USER_NAMESPACE)
+#if defined(IOP_TAKES_MNT_IDMAP)
+static int
+afs_linux_create(struct mnt_idmap *idmap, struct inode *dip,
+		 struct dentry *dp, umode_t mode, bool excl)
+#elif defined(IOP_TAKES_USER_NAMESPACE)
 static int
 afs_linux_create(struct user_namespace *mnt_userns, struct inode *dip,
 		 struct dentry *dp, umode_t mode, bool excl)
@@ -1949,7 +1962,11 @@ afs_linux_unlink(struct inode *dip, struct dentry *dp)
 }
 
 
-#if defined(IOP_TAKES_USER_NAMESPACE)
+#if defined(IOP_TAKES_MNT_IDMAP)
+static int
+afs_linux_symlink(struct mnt_idmap *idmap, struct inode *dip,
+		  struct dentry *dp, const char *target)
+#elif defined(IOP_TAKES_USER_NAMESPACE)
 static int
 afs_linux_symlink(struct user_namespace *mnt_userns, struct inode *dip,
 		  struct dentry *dp, const char *target)
@@ -1984,7 +2001,11 @@ out:
     return afs_convert_code(code);
 }
 
-#if defined(IOP_TAKES_USER_NAMESPACE)
+#if defined(IOP_TAKES_MNT_IDMAP)
+static int
+afs_linux_mkdir(struct mnt_idmap *idmap, struct inode *dip,
+		struct dentry *dp, umode_t mode)
+#elif defined(IOP_TAKES_USER_NAMESPACE)
 static int
 afs_linux_mkdir(struct user_namespace *mnt_userns, struct inode *dip,
 		struct dentry *dp, umode_t mode)
@@ -2064,7 +2085,13 @@ afs_linux_rmdir(struct inode *dip, struct dentry *dp)
 }
 
 
-#if defined(IOP_TAKES_USER_NAMESPACE)
+#if defined(IOP_TAKES_MNT_IDMAP)
+static int
+afs_linux_rename(struct mnt_idmap *idmap,
+		 struct inode *oldip, struct dentry *olddp,
+		 struct inode *newip, struct dentry *newdp,
+		 unsigned int flags)
+#elif defined(IOP_TAKES_USER_NAMESPACE)
 static int
 afs_linux_rename(struct user_namespace *mnt_userns,
 		 struct inode *oldip, struct dentry *olddp,
@@ -2088,7 +2115,7 @@ afs_linux_rename(struct inode *oldip, struct dentry *olddp,
     struct dentry *rehash = NULL;
 
 #if defined(HAVE_LINUX_INODE_OPERATIONS_RENAME_TAKES_FLAGS) || \
-    defined(IOP_TAKES_USER_NAMESPACE)
+    defined(IOP_TAKES_MNT_IDMAP) || defined(IOP_TAKES_USER_NAMESPACE)
     if (flags)
 	return -EINVAL;		/* no support for new flags yet */
 #endif
@@ -3384,7 +3411,10 @@ done:
  * Check access rights - returns error if can't check or permission denied.
  */
 
-#if defined(IOP_TAKES_USER_NAMESPACE)
+#if defined(IOP_TAKES_MNT_IDMAP)
+static int
+afs_linux_permission(struct mnt_idmap *idmap, struct inode *ip, int mode)
+#elif defined(IOP_TAKES_USER_NAMESPACE)
 static int
 afs_linux_permission(struct user_namespace *mnt_userns, struct inode *ip, int mode)
 #elif defined(IOP_PERMISSION_TAKES_FLAGS)
@@ -3613,7 +3643,8 @@ static struct address_space_operations afs_file_aops = {
   .readpages = 		afs_linux_readpages,
 #endif
   .writepage =		afs_linux_writepage,
-#if defined(STRUCT_ADDRESS_SPACE_OPERATIONS_HAS_DIRTY_FOLIO)
+#if defined(STRUCT_ADDRESS_SPACE_OPERATIONS_HAS_DIRTY_FOLIO) && \
+    defined(HAVE_LINUX_BLOCK_DIRTY_FOLIO)
   .dirty_folio =	block_dirty_folio,
 #else
   .set_page_dirty =	__set_page_dirty_buffers,
@@ -3715,6 +3746,7 @@ static struct inode_operations afs_symlink_iops = {
   .put_link =		afs_linux_put_link,
 #endif /* USABLE_KERNEL_PAGE_SYMLINK_CACHE */
   .setattr =		afs_notify_change,
+  .getattr =		afs_linux_getattr,
 };
 
 void
