@@ -98,7 +98,6 @@ afs_lock_t osi_fsplock;
 pthread_mutex_t usr_sleep_mutex;
 pthread_cond_t usr_sleep_cond;
 
-int call_syscall(long, long, long, long, long, long);
 int fork_syscall(long, long, long, long, long, long);
 
 
@@ -166,13 +165,13 @@ getf(int fd)
  * Every user is a super user
  */
 int
-afs_osi_suser(void *credp)
+afs_osi_suser(afs_ucred_t *credp)
 {
     return 1;
 }
 
 int
-afs_suser(void *credp)
+afs_suser(afs_ucred_t *credp)
 {
     return 1;
 }
@@ -181,17 +180,6 @@ afs_suser(void *credp)
  * These are no-ops in user space
  */
 
-/*
- * xflock should never fall through, the only files we know
- * about are AFS files
- */
-int
-usr_flock(void)
-{
-    usr_assert(0);
-    return 0;
-}
-
 /*
  * ioctl should never fall through, the only files we know
  * about are AFS files
