@@ -12,16 +12,8 @@
 /*
  * AFS system call opcodes
  */
-#ifdef KDUMP_KERNEL
-#include <afs/afs_args.h>
-#include <afs/afs_consts.h>
-#else
 #include "afs/afs_args.h"
 #include "afs/afs_consts.h"
-#endif
-
-/* jhash.h is a standalone header and is fine to pull into kernel code. */
-#include <opr/jhash.h>
 
 /*
  * afs_fsfragsize cannot be less than 1023, or some cache-tracking
@@ -42,24 +34,34 @@ enum afs_shutdown_state {
 };
 extern enum afs_shutdown_state afs_shuttingdown;
 
+/*
+ * The string that we use for the "device" we mount /afs on. That is, we're not
+ * mounted on a drive like /dev/sda, but instead mounted on "afs".
+ */
+#define AFS_MOUNT_STR "afs"
+#ifndef MOUNT_AFS
+# define MOUNT_AFS AFS_MOUNT_STR
+#endif
+
 /*
  * Macros to uniquely identify the AFS vfs struct
  */
 #define	AFS_VFSMAGIC		0x1234
 
-#if defined(UKERNEL)
-# if defined(AFS_USR_AIX_ENV) || defined(AFS_USR_SGI_ENV)
-#  define AFS_VFSFSID		AFS_MOUNT_AFS
-# else
-#  define AFS_VFSFSID		99
-# endif
-#elif defined(AFS_SUN5_ENV) || defined(AFS_HPUX90_ENV) || defined(AFS_LINUX_ENV)
-# define AFS_VFSFSID		99
-#elif defined(AFS_SGI_ENV)
-# define AFS_VFSFSID		afs_fstype
+/*
+ * Define AFS_VFSFSID, an id number corresponding to the AFS filesystem. On
+ * Irix, this is stored in a global var (afs_fstype); everywhere else, we have
+ * a constant. If we have a platform-defined value for this, use it (AFS_FSNO);
+ * otherwise, we just make up an arbitrary value here (99).
+ */
+#ifdef AFS_SGI_ENV
+# define AFS_VFSFSID	afs_fstype
+#elif defined(AFS_FSNO)
+# define AFS_VFSFSID	AFS_FSNO
 #else
-# define AFS_VFSFSID		AFS_MOUNT_AFS
+# define AFS_VFSFSID	99
 #endif
+
 /* use this value for reporting total space, free space, etc.
  * fake a high number to satisfy programs that use the statfs call to make sure
  * that there's enough space in the device partition before storing something
@@ -68,15 +70,15 @@ extern enum afs_shutdown_state afs_shuttingdown;
 #define AFS_VFS_FAKEFREE (2147483647)
 
 /* Moved from VNOPS/afs_vnop_flocks so can be used in prototypes */
-#if     defined(AFS_HPUX102_ENV)
-#define AFS_FLOCK       k_flock
+#if defined(UKERNEL)
+# define AFS_FLOCK usr_flock
+#elif defined(AFS_HPUX102_ENV)
+# define AFS_FLOCK k_flock
+#elif defined(AFS_SUN5_ENV) || (defined(AFS_LINUX_ENV) && !defined(AFS_LINUX_64BIT_KERNEL))
+# define AFS_FLOCK flock64
 #else
-#if     defined(AFS_SUN5_ENV) || (defined(AFS_LINUX_ENV) && !defined(AFS_LINUX_64BIT_KERNEL))
-#define AFS_FLOCK       flock64
-#else
-#define AFS_FLOCK       flock
-#endif /* AFS_SUN65_ENV */
-#endif /* AFS_HPUX102_ENV */
+# define AFS_FLOCK flock
+#endif /* UKERNEL */
 
 /* The following are various levels of afs debugging */
 #define	AFSDEB_GENERAL		1	/* Standard debugging */
@@ -95,7 +97,6 @@ extern enum afs_shutdown_state afs_shuttingdown;
 #define	NVOLS		64	/* hash table size for volume table */
 #define	NFENTRIES	256	/* hash table size for disk volume table */
 #define VCSIZEBITS	16	/* log of stat cache hash table size */
-#define	VCSIZE		(opr_jhash_size(VCSIZEBITS))
 #define CBRSIZE		512	/* call back returns hash table size */
 #define	PIGGYSIZE	1350	/* max piggyback size */
 #define	MAXVOLS		128	/* max vols we can store */
@@ -126,15 +127,27 @@ extern afs_int32 afs_rx_idledead_rep;
 
 struct sysname_info {
     char *name;
+    /*
+     * 'name_size' represents the number of bytes allocated in 'name'. If 0,
+     * 'name' points to existing memory, and shouldn't be freed.
+     */
+    size_t name_size;
     short offset;
-    signed char index, allocked;
+    signed char index;
 };
 
 /* flags to use with AFSOP_CACHEINIT */
 #define AFSCALL_INIT_MEMCACHE        0x1	/* use a memory-based cache */
 
+struct dcache;
+
 /* below here used only for kernel procedures */
 #ifdef KERNEL
+
+#include <opr/jhash.h>
+
+#define	VCSIZE		(opr_jhash_size(VCSIZEBITS))
+
 /* Store synchrony flags - SYNC means that data should be forced to server's
  * disk immediately upon completion. */
 #define AFS_ASYNC 	0
@@ -198,7 +211,7 @@ struct VenusFid {
     struct AFSFid Fid;
 };
 
-/* Temporary struct to be passed between afs_fid and afs_vget; in SunOS4.x we can only pass a maximum of 10 bytes for a handle (we ideally need 16!) */
+/* Temporary struct to be passed between afs_fid and afs_vget */
 struct SmallFid {
     afs_int32 Volume;
     afs_int32 CellAndUnique;
@@ -649,7 +662,7 @@ struct SimpleLocks {
 #define CCore		0x00000010	/* storing a core file, needed since we don't get an open */
 #define CDirty		0x00000020	/* file has been modified since first open (... O_RDWR) */
 #define CSafeStore	0x00000040	/* close must wait for store to finish (should be in fd) */
-#define CMAPPED		0x00000080	/* Mapped files; primarily used by SunOS 4.0.x */
+#define CMAPPED		0x00000080	/* Mapped files */
 #define CNSHARE		0x00000100	/* support O_NSHARE semantics */
 #define CLied		0x00000200
 #define CTruth		0x00000400
@@ -934,7 +947,7 @@ struct vcache {
 
 #if defined(AFS_LINUX_ENV)
     off_t next_seq_offset;	/* Next sequential offset (used by prefetch/readahead) */
-#elif defined(AFS_SUN5_ENV) || defined(AFS_SGI65_ENV)
+#elif defined(AFS_SUN5_ENV) || defined(AFS_SGI_ENV)
     off_t next_seq_blk_offset; /* accounted in blocks for Solaris & IRIX */
 #endif
 
@@ -946,18 +959,12 @@ struct vcache {
     unsigned int readdir_pid;   /* pid of the thread in readdir */
 #if defined(AFS_SGI_ENV)
     daddr_t lastr;		/* for read-ahead */
-#ifdef AFS_SGI64_ENV
     uint64_t vc_rwlockid;	/* kthread owning rwlock */
-#else
-    short vc_rwlockid;		/* pid of process owning rwlock */
-#endif
     short vc_locktrips;		/* # of rwlock reacquisitions */
     sema_t vc_rwlock;		/* vop_rwlock for afs */
     pgno_t mapcnt;		/* # of pages mapped */
     struct cred *cred;		/* last writer's cred */
-#ifdef AFS_SGI64_ENV
     struct bhv_desc vc_bhv_desc;	/* vnode's behavior data. */
-#endif
 #endif				/* AFS_SGI_ENV */
 #if defined(AFS_LINUX_ENV)
     cred_t *cred;		/* last writer's cred */
@@ -1001,35 +1008,13 @@ struct pagewriter {
 #if defined(AFS_SGI_ENV)
 #define AVCRWLOCK(avc)		(valusema(&(avc)->vc_rwlock) <= 0)
 
-/* SGI vnode rwlock macros and flags. */
-#ifndef AFS_SGI62_ENV
-/* The following are defined here. SGI 6.2 declares them in vnode.h */
-#define VRWLOCK_READ		0
-#define VRWLOCK_WRITE		1
-#define VRWLOCK_WRITE_DIRECT	2
-#endif
-
-#ifdef AFS_SGI53_ENV
-#ifdef AFS_SGI62_ENV
 #define AFS_RWLOCK_T vrwlock_t
-#else
-#define AFS_RWLOCK_T int
-#endif /* AFS_SGI62_ENV */
-#ifdef AFS_SGI64_ENV
 #include <ksys/behavior.h>
 #define AFS_RWLOCK(V,F) \
 	afs_rwlock(&VTOAFS(V)->vc_bhv_desc, (F));
 #define AFS_RWUNLOCK(V,F) \
 	afs_rwunlock(&VTOAFS(V)->vc_bhv_desc, (F));
 
-#else
-#define AFS_RWLOCK(V,F) afs_rwlock((vnode_t *)(V), (F) )
-#define AFS_RWUNLOCK(V,F) afs_rwunlock((vnode_t *)(V), (F) )
-#endif
-#else /* AFS_SGI53_ENV */
-#define AFS_RWLOCK(V,F) afs_rwlock((V))
-#define AFS_RWUNLOCK(V,F) afs_rwunlock((V))
-#endif /* AFS_SGI53_ENV */
 #endif /* AFS_SGI_ENV */
 
 struct vcxstat {
@@ -1132,7 +1117,7 @@ typedef user_addr_t iparmtype; /* 64 bit */
 typedef user_addr_t uparmtype; /* 64 bit */
 #else
 typedef char * uparmtype;
-#ifdef AFS_SGI65_ENV
+#ifdef AFS_SGI_ENV
 typedef afs_uint32 iparmtype;
 #else
 typedef long iparmtype;
@@ -1187,7 +1172,7 @@ struct afs_fheader {
 
 #if defined(AFS_CACHE_VNODE_PATH)
 typedef char *afs_ufs_dcache_id_t;
-#elif defined(AFS_SGI61_ENV) || defined(AFS_SUN5_64BIT_ENV)
+#elif defined(AFS_SGI_ENV) || defined(AFS_SUN5_64BIT_ENV)
 /* Using ino64_t here so that user level debugging programs compile
  * the size correctly.
  */
@@ -1412,6 +1397,78 @@ extern struct brequest afs_brs[NBRS];	/* request structures */
 #define AFS_VOLCHECK_MTPTS	0x4	/* mount point invalidation also */
 #define AFS_VOLCHECK_FORCE	0x8	/* do all forcibly */
 
+/*
+ * Wrappers for access to credentials structure members
+ * Linux uses the kernel cred structure if available, with the
+ * wrappers defined in LINUX/osi_machdep.h
+ */
+#if defined(AFS_NBSD40_ENV)
+/* in osi_machdep.h as expected */
+#elif defined (AFS_DARWIN110_ENV)
+#define afs_cr_uid(cred) kauth_cred_getuid((kauth_cred_t)(cred))
+#define afs_cr_gid(cred) kauth_cred_getgid((kauth_cred_t)(cred))
+#elif !(defined(AFS_LINUX_ENV) && defined(STRUCT_TASK_STRUCT_HAS_CRED))
+#define afs_cr_uid(cred) ((cred)->cr_uid)
+#define afs_cr_gid(cred) ((cred)->cr_gid)
+#if !defined(AFS_OBSD_ENV)
+#define afs_cr_ruid(cred) ((cred)->cr_ruid)
+#define afs_cr_rgid(cred) ((cred)->cr_rgid)
+#endif
+
+#if !defined(AFS_DARWIN110_ENV)
+static_inline void
+afs_set_cr_uid(afs_ucred_t *cred, uid_t uid) {
+    cred->cr_uid = uid;
+}
+static_inline void
+afs_set_cr_gid(afs_ucred_t *cred, gid_t gid) {
+    cred->cr_gid = gid;
+}
+#if !defined(AFS_OBSD_ENV)
+static_inline void
+afs_set_cr_ruid(afs_ucred_t *cred, uid_t uid) {
+    cred->cr_ruid = uid;
+}
+static_inline void
+afs_set_cr_rgid(afs_ucred_t *cred, gid_t gid) {
+    cred->cr_rgid = gid;
+}
+#endif /* ! AFS_OBSD_ENV */
+#endif /* ! AFS_DARWIN110_ENV */
+#endif
+
+/*
+ * Various definitions for osi_sleep and its event hash table
+ * DFBSD has no osi_sleep, and HPUX has its own hack for this stuff
+ */
+#define AFS_EVHASHSIZE	128	/* size of afs_evhasht, must be power of 2 */
+
+typedef struct afs_event {
+    struct afs_event *next;	/* next in hash chain */
+    char *event;		/* lwp event: an address */
+    int refcount;		/* Is it in use? */
+    int seq;			/* Sequence number: this is incremented
+				 * by wakeup calls; wait will not return until
+				 * it changes */
+#if defined(AFS_AIX_ENV)
+    tid_t cond;
+#elif defined(AFS_DARWIN_ENV)
+# ifdef AFS_DARWIN80_ENV
+    lck_mtx_t *lck;
+    thread_t owner;
+# endif
+    /* no cond member */
+#elif defined(AFS_FBSD_ENV) || defined(AFS_OBSD_ENV)
+    int cond;			/* "all this gluck should probably be replaced by CVs" */
+#elif defined(AFS_LINUX_ENV)
+    wait_queue_head_t cond;
+#elif defined(AFS_NBSD_ENV) || defined(AFS_SUN5_ENV) || defined(AFS_SGI_ENV)
+    kcondvar_t cond;		/* Currently associated condition variable */
+#endif
+} afs_event_t;
+
+extern afs_event_t *afs_evhasht[AFS_EVHASHSIZE];	/* Hash table for events */
+
 #endif /* KERNEL */
 
 #define	AFS_FSPORT	    ((unsigned short) htons(7000))
@@ -1471,16 +1528,16 @@ extern struct brequest afs_brs[NBRS];	/* request structures */
 
 /* get a file's serial number from a vnode */
 #ifndef afs_vnodeToInumber
-#if defined(AFS_SGI62_ENV) || defined(AFS_HAVE_VXFS) || defined(AFS_DARWIN_ENV)
+#if defined(AFS_SGI_ENV) || defined(AFS_HAVE_VXFS) || defined(AFS_DARWIN_ENV)
 #define afs_vnodeToInumber(V) VnodeToIno(V)
 #else
 #define afs_vnodeToInumber(V) (VTOI(V)->i_number)
-#endif /* AFS_SGI62_ENV */
+#endif /* AFS_SGI_ENV */
 #endif
 
 /* get a file's device number from a vnode */
 #ifndef afs_vnodeToDev
-#if defined(AFS_SGI62_ENV) || defined(AFS_HAVE_VXFS) || defined(AFS_DARWIN_ENV)
+#if defined(AFS_SGI_ENV) || defined(AFS_HAVE_VXFS) || defined(AFS_DARWIN_ENV)
 #define afs_vnodeToDev(V) VnodeToDev(V)
 #elif defined(UKERNEL)
 #define afs_vnodeToDev(V) (VTOI(V) ? (VTOI(V)->i_dev) : (-1))
@@ -1494,6 +1551,8 @@ extern struct brequest afs_brs[NBRS];	/* request structures */
    except with libuafs, in which case it is actually defined */
 
 struct buf;
+struct osi_file;
+struct afs_FetchOutput;
 
 struct rxfs_storeVariables {
     struct rx_call *call;
@@ -1543,46 +1602,6 @@ extern int afs_fakestat_enable;
 extern int afs_rmtsys_enable;
 extern int afsd_dynamic_vcaches;
 
-/*
- * Wrappers for access to credentials structure members
- * Linux uses the kernel cred structure if available, with the
- * wrappers defined in LINUX/osi_machdep.h
- */
-#if defined(AFS_NBSD40_ENV)
-/* in osi_machdep.h as expected */
-#elif defined (AFS_DARWIN110_ENV)
-#define afs_cr_uid(cred) kauth_cred_getuid((kauth_cred_t)(cred))
-#define afs_cr_gid(cred) kauth_cred_getgid((kauth_cred_t)(cred))
-#elif !(defined(AFS_LINUX_ENV) && defined(STRUCT_TASK_STRUCT_HAS_CRED))
-#define afs_cr_uid(cred) ((cred)->cr_uid)
-#define afs_cr_gid(cred) ((cred)->cr_gid)
-#if !defined(AFS_OBSD_ENV)
-#define afs_cr_ruid(cred) ((cred)->cr_ruid)
-#define afs_cr_rgid(cred) ((cred)->cr_rgid)
-#endif
-
-#if !defined(AFS_DARWIN110_ENV)
-static_inline void
-afs_set_cr_uid(afs_ucred_t *cred, uid_t uid) {
-    cred->cr_uid = uid;
-}
-static_inline void
-afs_set_cr_gid(afs_ucred_t *cred, gid_t gid) {
-    cred->cr_gid = gid;
-}
-#if !defined(AFS_OBSD_ENV)
-static_inline void
-afs_set_cr_ruid(afs_ucred_t *cred, uid_t uid) {
-    cred->cr_ruid = uid;
-}
-static_inline void
-afs_set_cr_rgid(afs_ucred_t *cred, gid_t gid) {
-    cred->cr_rgid = gid;
-}
-#endif /* ! AFS_OBSD_ENV */
-#endif /* ! AFS_DARWIN110_ENV */
-#endif
-
 #ifdef AFS_SUN5_ENV
 
 /** The 32 bit OS expects the members of this structure to be 32 bit
@@ -1602,36 +1621,4 @@ struct afssysa {
 extern int Afs_syscall(struct afssysa *uap, rval_t *rvp);
 #endif /* AFS_SUN5_ENV */
 
-/*
- * Various definitions for osi_sleep and its event hash table
- * DFBSD and SUNOS have no osi_sleep, and HPUX has its own hack for this stuff
- */
-#define AFS_EVHASHSIZE	128	/* size of afs_evhasht, must be power of 2 */
-
-typedef struct afs_event {
-    struct afs_event *next;	/* next in hash chain */
-    char *event;		/* lwp event: an address */
-    int refcount;		/* Is it in use? */
-    int seq;			/* Sequence number: this is incremented
-				 * by wakeup calls; wait will not return until
-				 * it changes */
-#if defined(AFS_AIX_ENV)
-    tid_t cond;
-#elif defined(AFS_DARWIN_ENV)
-# ifdef AFS_DARWIN80_ENV
-    lck_mtx_t *lck;
-    thread_t owner;
-# endif
-    /* no cond member */
-#elif defined(AFS_FBSD_ENV) || defined(AFS_OBSD_ENV)
-    int cond;			/* "all this gluck should probably be replaced by CVs" */
-#elif defined(AFS_LINUX_ENV)
-    wait_queue_head_t cond;
-#elif defined(AFS_NBSD_ENV) || defined(AFS_SUN5_ENV) || defined(AFS_SGI_ENV)
-    kcondvar_t cond;		/* Currently associated condition variable */
-#endif
-} afs_event_t;
-
-extern afs_event_t *afs_evhasht[AFS_EVHASHSIZE];	/* Hash table for events */
-
 #endif /* _AFS_H_ */
