@@ -20,10 +20,8 @@
 #include "afs/sysincludes.h"	/*Standard vendor system headers */
 #include "afsincludes.h"	/*AFS-based standard headers */
 #include "afs/afs_stats.h"	/*Cache Manager stats */
+#include "afs/opr.h"
 #include "afs/afs_args.h"
-#if defined(UKERNEL)
-# include "roken.h"
-#endif
 
 afs_int32 afs_allCBs = 0;	/*Break callbacks on all objects */
 afs_int32 afs_oddCBs = 0;	/*Break callbacks on dirs */
@@ -845,6 +843,8 @@ SRXAFSCB_GetXStats(struct rx_call *a_call, afs_int32 a_clientVersionNum,
     afs_int32 dataBytes;	/*Bytes in data buffer */
     XSTATS_DECLS;
 
+    opr_StaticAssert(sizeof(osi_timeval32_t) == SIZEOF_OSI_TIMEVAL32_T);
+
     RX_AFS_GLOCK();
 
     XSTATS_START_CMTIME(AFS_STATS_CM_RPCIDX_GETXSTATS);
