@@ -17,7 +17,7 @@
 #include "rx/rx_globals.h"
 #if !defined(UKERNEL) && !defined(AFS_LINUX_ENV)
 #include "net/if.h"
-#ifdef AFS_SGI62_ENV
+#ifdef AFS_SGI_ENV
 #include "h/hashing.h"
 #endif
 #if !defined(AFS_HPUX110_ENV) && !defined(AFS_DARWIN_ENV)
@@ -29,13 +29,6 @@
 struct afs_icl_set *afs_iclSetp = (struct afs_icl_set *)0;
 struct afs_icl_set *afs_iclLongTermSetp = (struct afs_icl_set *)0;
 
-/* Matches below where ICL_APPENDLONG is 2 INT32s */
-#if (defined(AFS_SGI61_ENV) && (_MIPS_SZLONG==64)) || (defined(AFS_AIX51_ENV) && defined(AFS_64BIT_KERNEL)) || defined(AFS_DARWIN_ENV) && defined(__amd64__)
-#define ICL_LONG 2
-#else
-#define ICL_LONG 1
-#endif
-
 int afs_icl_sizeofLong = ICL_LONG;
 
 int afs_icl_inited = 0;
@@ -127,15 +120,15 @@ Afscall_icl(long opcode, long p1, long p2, long p3, long p4, long *retval)
     afs_int32 code;
     struct afs_icl_log *logp;
     struct afs_icl_set *setp;
-#if defined(AFS_SGI61_ENV) || defined(AFS_SUN5_ENV) || defined(AFS_DARWIN_ENV) || defined(AFS_XBSD_ENV)
+#if defined(AFS_SGI_ENV) || defined(AFS_SUN5_ENV) || defined(AFS_DARWIN_ENV) || defined(AFS_XBSD_ENV)
     size_t temp;
-#else /* AFS_SGI61_ENV */
+#else /* AFS_SGI_ENV */
 #if defined(AFS_AIX51_ENV) && defined(AFS_64BIT_KERNEL)
     afs_uint64 temp;
 #else
     afs_uint32 temp;
 #endif
-#endif /* AFS_SGI61_ENV */
+#endif /* AFS_SGI_ENV */
     char tname[65];
     afs_int32 startCookie;
     afs_int32 allocated;
@@ -725,6 +718,7 @@ afs_icl_CreateLogWithFlags(char *name, afs_int32 logSize, afs_uint32 flags,
 			   struct afs_icl_log **outLogpp)
 {
     struct afs_icl_log *logp;
+    size_t namelen;
 
     /* add into global list under lock */
     ObtainWriteLock(&afs_icl_lock, 183);
@@ -750,8 +744,9 @@ afs_icl_CreateLogWithFlags(char *name, afs_int32 logSize, afs_uint32 flags,
     memset((caddr_t) logp, 0, sizeof(*logp));
 
     logp->refCount = 1;
-    logp->name = osi_AllocSmallSpace(strlen(name) + 1);
-    strcpy(logp->name, name);
+    namelen = strlen(name) + 1;
+    logp->name = osi_AllocSmallSpace(namelen);
+    osi_Assert(strlcpy(logp->name, name, namelen) < namelen);
     LOCK_INIT(&logp->lock, "logp lock");
     logp->logSize = logSize;
     logp->datap = NULL;		/* don't allocate it until we need it */
@@ -1126,6 +1121,7 @@ afs_icl_CreateSetWithFlags(char *name, struct afs_icl_log *baseLogp,
     struct afs_icl_set *setp;
     int i;
     afs_int32 states = ICL_DEFAULT_SET_STATES;
+    size_t namelen;
 
     ObtainWriteLock(&afs_icl_lock, 197);
     if (!afs_icl_inited)
@@ -1166,8 +1162,9 @@ afs_icl_CreateSetWithFlags(char *name, struct afs_icl_log *baseLogp,
      * the afs_icl_lock is still held, and thus the obtain can't block.
      */
     ObtainWriteLock(&setp->lock, 199);
-    setp->name = osi_AllocSmallSpace(strlen(name) + 1);
-    strcpy(setp->name, name);
+    namelen = strlen(name) + 1;
+    setp->name = osi_AllocSmallSpace(namelen);
+    osi_Assert(strlcpy(setp->name, name, namelen) < namelen);
     setp->nevents = ICL_DEFAULTEVENTS;
     setp->eventFlags = afs_osi_Alloc(ICL_DEFAULTEVENTS);
     osi_Assert(setp->eventFlags != NULL);
