@@ -15,7 +15,8 @@
 #include "afsincludes.h"	/* Afs-based standard headers */
 #include "afs/afs_stats.h"	/* afs statistics */
 #ifdef AFS_AIX_ENV
-#include <sys/adspace.h>	/* for vm_att(), vm_det() */
+# include <sys/adspace.h>	/* for vm_att(), vm_det() */
+# include <sys/malloc.h>        /* pinned_heap */
 #endif
 
 /* osi_Init -- do once per kernel installation initialization.
@@ -31,11 +32,8 @@ extern void init_hckernel_mutex(void);
 
 afs_lock_t afs_ftf;		/* flush text lock */
 
-#ifdef AFS_SGI53_ENV
+#ifdef AFS_SGI_ENV
 lock_t afs_event_lock;
-#endif
-
-#ifdef AFS_SGI64_ENV
 flid_t osi_flid;
 #endif
 
@@ -45,10 +43,6 @@ afs_ucred_t *afs_osi_credp;
 kmutex_t afs_global_lock;
 #endif
 
-#if defined(AFS_SGI_ENV) && !defined(AFS_SGI64_ENV)
-long afs_global_owner;
-#endif
-
 #if defined(AFS_DARWIN_ENV)
 thread_t afs_global_owner;
 #ifdef AFS_DARWIN80_ENV
@@ -101,24 +95,27 @@ osi_Init(void)
 	  crdup(osi_curcred());
 #elif defined(AFS_SUN5_ENV)
 	afs_osi_credp = kcred;
+#elif defined(AFS_DARWIN_ENV)
+	afs_osi_credp = afs_osi_Alloc(sizeof(*afs_osi_credp));
+	osi_Assert(afs_osi_credp != NULL);
+	memset(afs_osi_credp, 0, sizeof(*afs_osi_credp));
+# if defined(AFS_DARWIN80_ENV)
+	afs_osi_credp->cr_ref = 1; /* kauth_cred_get_ref needs 1 existing ref */
+# endif
 #else
 	memset(&afs_osi_cred, 0, sizeof(afs_ucred_t));
 #if defined(AFS_LINUX_ENV)
         afs_set_cr_group_info(&afs_osi_cred, groups_alloc(0));
 #endif
-#if defined(AFS_DARWIN80_ENV)
-        afs_osi_cred.cr_ref = 1; /* kauth_cred_get_ref needs 1 existing ref */
-#else
-# if !(defined(AFS_LINUX_ENV) && defined(STRUCT_TASK_STRUCT_HAS_CRED))
+#if !(defined(AFS_LINUX_ENV) && defined(STRUCT_TASK_STRUCT_HAS_CRED))
 	crhold(&afs_osi_cred);  /* don't let it evaporate */
-# endif
 #endif
 
 	afs_osi_credp = &afs_osi_cred;
 #endif
 	afs_osicred_initialized = 1;
     }
-#ifdef AFS_SGI64_ENV
+#ifdef AFS_SGI_ENV
     osi_flid.fl_pid = osi_flid.fl_sysid = 0;
 #endif
 
@@ -245,7 +242,7 @@ shutdown_osisleep(void)
 		afs_warn("nonzero refcount in shutdown_osisleep()\n");
 	    } else {
 #if defined(AFS_AIX_ENV)
-		xmfree(tmp);
+		xmfree(tmp, pinned_heap);
 #elif defined(AFS_FBSD_ENV)
 		afs_osi_Free(tmp, sizeof(*tmp));
 #elif defined(AFS_SGI_ENV) || defined(AFS_XBSD_ENV) || defined(AFS_SUN5_ENV)
@@ -261,7 +258,7 @@ shutdown_osisleep(void)
 
 #if !defined(AFS_OBSD_ENV) && !defined(AFS_NBSD40_ENV)
 int
-afs_osi_suser(void *cr)
+afs_osi_suser(afs_ucred_t *cr)
 {
 #if defined(AFS_SUN510_ENV)
     return (priv_policy(cr, PRIV_SYS_SUSER_COMPAT, B_FALSE, EPERM, NULL) == 0);
