@@ -558,7 +558,7 @@ extern void afs_osi_Invisible(void);
 extern void shutdown_osi(void);
 extern void shutdown_osinet(void);
 extern void shutdown_osisleep(void);
-extern int afs_osi_suser(void *credp);
+extern int afs_osi_suser(afs_ucred_t *credp);
 extern void afs_osi_TraverseProcTable(void);
 #if defined(KERNEL) && !defined(UKERNEL)
 extern const afs_ucred_t *afs_osi_proc2cred(afs_proc_t * pr);
@@ -650,8 +650,6 @@ extern int uiomove(char *dp, int length, uio_flag_t rw, struct uio *uiop);
 extern void osi_linux_free_inode_pages(void);
 extern void osi_linux_mask(void);
 extern void osi_linux_unmaskrxk(void);
-extern int setpag(cred_t ** cr, afs_uint32 pagvalue, afs_uint32 * newpag,
-		  int change_parent);
 #endif
 
 
@@ -679,7 +677,7 @@ extern int afs_syscall_icreate(dev_t, long, long, long, long, long,
 extern int afs_syscall_iopen(dev_t, int, int, rval_t *, afs_ucred_t *);
 extern int afs_syscall_iincdec(dev_t, int, int, int, rval_t *,
 			       afs_ucred_t *);
-#elif defined(AFS_SGI65_ENV)
+#elif defined(AFS_SGI_ENV)
 extern int afs_syscall_icreate(afs_uint32, afs_uint32, afs_uint32, afs_uint32, afs_uint32, afs_uint32, rval_t *);
 extern int afs_syscall_iopen(int, ino_t, int, rval_t *);
 extern int afs_syscall_iincdec(int, int, int, int);
@@ -716,28 +714,30 @@ extern int afs_osi_Write(struct osi_file *afile, afs_int32 offset,
 extern int afs_osi_MapStrategy(int (*aproc) (struct buf * bp),
 			       struct buf *bp);
 extern void shutdown_osifile(void);
+#if defined(AFS_HAVE_VXFS) || defined(AFS_DARWIN_ENV)
+extern void afs_InitDualFSCacheOps(struct vnode *vp);
+#endif
 
 
 /* ARCH/osi_groups.c */
 #if defined(UKERNEL)
 extern int usr_setpag(afs_ucred_t **cred, afs_uint32 pagvalue,
 		      afs_uint32 * newpag, int change_parent);
-#else
-# if defined AFS_XBSD_ENV
-#  if !defined(AFS_DFBSD_ENV)
-#   if defined(AFS_FBSD_ENV)
+#elif defined(AFS_LINUX_ENV)
+extern int setpag(cred_t **cr, afs_uint32 pagvalue, afs_uint32 *newpag,
+		  int change_parent);
+#elif defined(AFS_FBSD_ENV)
 extern int setpag(struct thread *td, struct ucred **cred, afs_uint32 pagvalue,
 		  afs_uint32 * newpag, int change_parent);
-
-#   elif defined(AFS_NBSD_ENV)
+#elif defined(AFS_NBSD_ENV)
 extern int setpag(afs_proc_t *proc, afs_ucred_t **cred, afs_uint32 pagvalue,
 		  afs_uint32 * newpag, int change_parent);
-#   else
+#elif defined(AFS_OBSD_ENV)
 extern int setpag(afs_proc_t *proc, struct ucred **cred, afs_uint32 pagvalue,
 		  afs_uint32 * newpag, int change_parent);
-#   endif /* AFS_FBSD_ENV */
-#  endif /* ! AFS_DFBSD_ENV */
-# endif /* AFS_XBSD_ENV */
+#elif defined(AFS_DARWIN_ENV)
+extern int setpag(struct proc *proc, struct ucred **cred, afs_uint32 pagvalue,
+		  afs_uint32 *newpag, afs_uint32 change_parent);
 #endif /* UKERNEL */
 
 #if defined(AFS_LINUX_ENV) || defined(AFS_PAG_ONEGROUP_ENV)
@@ -1032,7 +1032,6 @@ extern void print_internet_address(char *preamble, struct srvAddr *sa,
 				   struct rx_connection *rxconn);
 extern afs_int32 afs_data_pointer_to_int32(const void *p);
 
-extern void afs_CheckLocks(void);
 extern int afs_badop(void);
 extern int afs_noop(void);
 extern afs_int32 afs_data_pointer_to_int32(const void *p);
@@ -1174,7 +1173,7 @@ extern afs_int32 afs_GetAccessBits(struct vcache *avc,
 				   struct vrequest *areq);
 extern int afs_AccessOK(struct vcache *avc, afs_int32 arights,
 			struct vrequest *areq, afs_int32 check_mode_bits);
-#if defined(AFS_SUN5_ENV) || (defined(AFS_SGI_ENV) && !defined(AFS_SGI65_ENV))
+#if defined(AFS_SUN5_ENV)
 extern int afs_access(OSI_VC_DECL(avc), afs_int32 amode, int flags,
 		      afs_ucred_t *acred);
 #else
@@ -1208,15 +1207,15 @@ extern int afs_CreateAttr(struct vattr **out);
 extern void afs_DestroyAttr(struct vattr *vattr);
 
 /* VNOPS/afs_vnop_create.c */
-#ifdef AFS_SGI64_ENV
+#ifdef AFS_SGI_ENV
 extern int afs_create(OSI_VC_DECL(adp), char *aname, struct vattr *attrs,
 		      int flags, int amode, struct vcache **avcp,
 		      afs_ucred_t *acred);
-#else /* AFS_SGI64_ENV */
+#else /* AFS_SGI_ENV */
 extern int afs_create(OSI_VC_DECL(adp), char *aname, struct vattr *attrs,
 		      enum vcexcl aexcl, int amode, struct vcache **avcp,
 		      afs_ucred_t *acred);
-#endif /* AFS_SGI64_ENV */
+#endif /* AFS_SGI_ENV */
 extern int afs_LocalHero(struct vcache *avc,
 			 struct dcache *adc,
 			 AFSFetchStatus * astat, int aincr);
@@ -1298,7 +1297,7 @@ extern int afs_lookup(OSI_VC_DECL(adp), char *aname, struct vcache **avcp,
 #endif
 
 /* VNOPS/afs_vnop_open.c */
-#ifdef AFS_SGI64_ENV
+#ifdef AFS_SGI_ENV
 extern int afs_open(bhv_desc_t * bhv, struct vcache **avcp, afs_int32 aflags,
 		    afs_ucred_t *acred);
 #else
@@ -1381,17 +1380,9 @@ extern int afs_DoPartialWrite(struct vcache *avc,
 			      struct vrequest *areq);
 extern int afs_closex(struct file *afd);
 
-#ifdef AFS_SGI65_ENV
+#ifdef AFS_SGI_ENV
 extern int afs_close(OSI_VC_DECL(avc), afs_int32 aflags,
 		     lastclose_t lastclose, afs_ucred_t *acred);
-#elif defined(AFS_SGI64_ENV)
-extern int afs_close(OSI_VC_DECL(avc), afs_int32 aflags,
-		     lastclose_t lastclose, off_t offset,
-		     afs_ucred_t *acred, struct flid *flp);
-#elif defined(AFS_SGI_ENV)
-extern int afs_close(OSI_VC_DECL(avc), afs_int32 aflags,
-		     lastclose_t lastclose, off_t offset,
-		     afs_ucred_t *acred);
 #elif defined(AFS_SUN5_ENV)
 extern int afs_close(OSI_VC_DECL(avc), afs_int32 aflags, int count,
 		     offset_t offset, afs_ucred_t *acred);
@@ -1400,10 +1391,10 @@ extern int afs_close(OSI_VC_DECL(avc), afs_int32 aflags,
 		     afs_ucred_t *acred);
 #endif
 
-#if defined(AFS_SGI65_ENV)
+#if defined(AFS_SGI_ENV)
 extern int afs_fsync(OSI_VC_DECL(avc), int flags, afs_ucred_t *acred,
 		     off_t start, off_t stop);
-#elif defined(AFS_SGI_ENV) || defined(AFS_SUN5_ENV)
+#elif defined(AFS_SUN5_ENV)
 extern int afs_fsync(OSI_VC_DECL(avc), int flag, afs_ucred_t *acred);
 #else
 extern int afs_fsync(OSI_VC_DECL(avc), afs_ucred_t *acred);
@@ -1450,7 +1441,7 @@ extern void afs_ntohuuid(afsUUID * uuidp);
 extern afs_int32 afs_uuid_create(afsUUID * uuid);
 extern u_short afs_uuid_hash(afsUUID * uuid);
 
-#if defined(AFS_SUN5_ENV) || defined(AFS_LINUX_ENV) || defined(AFS_AIX_ENV) || defined(AFS_DARWIN_ENV) || defined(AFS_XBSD_ENV) || defined(AFS_HPUX_ENV) || defined(AFS_SGI62_ENV) || defined(UKERNEL)
+#if defined(AFS_SUN5_ENV) || defined(AFS_LINUX_ENV) || defined(AFS_AIX_ENV) || defined(AFS_DARWIN_ENV) || defined(AFS_XBSD_ENV) || defined(AFS_HPUX_ENV) || defined(AFS_SGI_ENV) || defined(UKERNEL)
 #include "osi_prototypes.h"
 #endif
 
