@@ -501,7 +501,7 @@ struct afs_MeanStats {
     AFS_CS(fprf)		/* afs_resource.c */ \
     AFS_CS(fprint)		/* afs_resource.c */ \
     AFS_CS(fprintn)		/* afs_resource.c */ \
-    AFS_CS(afs_CheckLocks)	/* afs_resource.c */ \
+    AFS_CS(afs_CheckLocks)	/* UNUSED */ \
     AFS_CS(puttofile)		/* afs_resource.c */ \
     AFS_CS(shutdown_AFS)	/* afs_resource.c */ \
     AFS_CS(afs_CheckCacheResets)	/* afs_resource.c */ \
@@ -659,7 +659,8 @@ struct afs_MeanStats {
     AFS_CS(PPrefetchFromTape)   /* afs_pioctl.c */ \
     AFS_CS(PFlushAllVolumeData)	/* afs_pioctl.c */ \
     AFS_CS(afs_InitVolSlot)     /* afs_volume.c */ \
-    AFS_CS(afs_SetupVolSlot)    /* afs_volume.c */
+    AFS_CS(afs_SetupVolSlot)    /* afs_volume.c */ \
+    AFS_CS(PGetLiteralFID)	/* afs_pioctl.c */
 
 struct afs_CMCallStats {
 #define AFS_CS(call) afs_int32 C_ ## call;
