@@ -53,9 +53,9 @@ afs_int32 afs_vcount = 0;	/* number of vcache in use now */
 int afsvnumbers = 0;
 #endif
 
-#ifdef AFS_SGI64_ENV
+#ifdef AFS_SGI_ENV
 char *makesname();
-#endif /* AFS_SGI64_ENV */
+#endif /* AFS_SGI_ENV */
 
 /* Exported variables */
 afs_rwlock_t afs_xvcdirty;	/*Lock: discon vcache dirty list mgmt */
@@ -313,20 +313,27 @@ void
 afs_InactiveVCache(struct vcache *avc, afs_ucred_t *acred)
 {
     AFS_STATCNT(afs_inactive);
+
+    ObtainWriteLock(&avc->lock, 68);
+
     if (avc->f.states & CDirty) {
 	/* we can't keep trying to push back dirty data forever.  Give up. */
 	afs_InvalidateAllSegments(avc);	/* turns off dirty bit */
     }
-    avc->f.states &= ~CMAPPED;	/* mainly used by SunOS 4.0.x */
+    avc->f.states &= ~CMAPPED;
     avc->f.states &= ~CDirty;	/* Turn it off */
     if (avc->f.states & CUnlinked) {
-	if (CheckLock(&afs_xvcache) || CheckLock(&afs_xdcache)) {
+	if (CheckLock(&afs_xvcache) || CheckLock(&afs_xdcache) ||
+	    osi_ShouldDeferRemunlink(avc)) {
 	    avc->f.states |= CUnlinkedDel;
+	    ReleaseWriteLock(&avc->lock);
 	    return;
 	}
+	ReleaseWriteLock(&avc->lock);
 	afs_remunlink(avc, 1);	/* ignore any return code */
+	return;
     }
-
+    ReleaseWriteLock(&avc->lock);
 }
 #endif
 
@@ -2941,12 +2948,6 @@ afs_vcacheInit(int astatSize)
 	tvc->vc_rwlockid = OSI_NO_LOCKID;
 	initnsema(&tvc->vc_rwlock, 1,
 		  makesname(name, "vrw", tvc->v.v_number));
-#ifndef	AFS_SGI53_ENV
-	initnsema(&tvc->v.v_sync, 0, makesname(name, "vsy", tvc->v.v_number));
-#endif
-#ifndef AFS_SGI62_ENV
-	initnlock(&tvc->v.v_lock, makesname(name, "vlk", tvc->v.v_number));
-#endif /* AFS_SGI62_ENV */
     }
 #endif
     QInit(&VLRU);
@@ -3063,7 +3064,6 @@ afs_DisconGiveUpCallbacks(void)
 {
     int i;
     struct vcache *tvc;
-    int nq=0;
 
     ObtainWriteLock(&afs_xvcache, 1002); /* XXX - should be a unique number */
 
@@ -3074,7 +3074,6 @@ afs_DisconGiveUpCallbacks(void)
 	    int slept = 0;
             if (afs_QueueVCB(tvc, &slept)) {
                 tvc->callback = NULL;
-                nq++;
             }
 	    if (slept) {
 		goto retry;
