@@ -44,6 +44,7 @@
 #include <afs/afsutil.h>
 #include <afs/fileutil.h>
 #include <afs/audit.h>
+#include <afs/authcon.h>
 #include <afs/cellconfig.h>
 #include <afs/cmd.h>
 
@@ -883,6 +884,7 @@ main(int argc, char **argv, char **envp)
     int DoPeerRPCStats = 0;
     int DoProcessRPCStats = 0;
     struct stat sb;
+    struct afsconf_bsso_info bsso;
 #ifndef AFS_NT40_ENV
     int nofork = 0;
 #endif
@@ -910,6 +912,8 @@ main(int argc, char **argv, char **envp)
     osi_audit_init();
     signal(SIGFPE, bozo_insecureme);
 
+    memset(&bsso, 0, sizeof(bsso));
+
 #ifdef AFS_NT40_ENV
     /* Initialize winsock */
     if (afs_winsockInit() < 0) {
@@ -1149,12 +1153,6 @@ main(int argc, char **argv, char **envp)
     /* opened the cell databse */
     bozo_confdir = tdir;
 
-    if (afsconf_CountKeys(bozo_confdir) == 0) {
-	bozo_Log("WARNING: No encryption keys found! "
-		 "All authenticated accesses will fail. "
-		 "Run akeyconvert or asetkey to import encryption keys.\n");
-    }
-
     code = bnode_Init();
     if (code) {
 	printf("bosserver: could not init bnode package, code %d\n", code);
@@ -1240,7 +1238,10 @@ main(int argc, char **argv, char **envp)
     rx_SetRxStatUserOk(bozo_rxstat_userok);
 
     afsconf_SetNoAuthFlag(tdir, noAuth);
-    afsconf_BuildServerSecurityObjects(tdir, &securityClasses, &numClasses);
+
+    bsso.dir = tdir;
+    bsso.logger = bozo_Log;
+    afsconf_BuildServerSecurityObjects_int(&bsso, &securityClasses, &numClasses);
 
     if (DoPidFiles) {
 	bozo_CreatePidFile("bosserver", NULL, getpid());
@@ -1253,8 +1254,12 @@ main(int argc, char **argv, char **envp)
     rx_SetMaxProcs(tservice, 4);
     rx_SetStackSize(tservice, BOZO_LWP_STACKSIZE);	/* so gethostbyname works (in cell stuff) */
     if (rxkadDisableDotCheck) {
-        rx_SetSecurityConfiguration(tservice, RXS_CONFIG_FLAGS,
-                                    (void *)RXS_CONFIG_FLAGS_DISABLE_DOTCHECK);
+	code = rx_SetSecurityConfiguration(tservice, RXS_CONFIG_FLAGS,
+					   (void *)RXS_CONFIG_FLAGS_DISABLE_DOTCHECK);
+	if (code) {
+	    bozo_Log("Failed to allow dotted principals: code %d\n", code);
+	    exit(1);
+	}
     }
 
     tservice =
