@@ -10,20 +10,14 @@
 #include <afsconfig.h>
 #include <afs/stds.h>
 
+#include <roken.h>
 
-#include <sys/types.h>
-#ifdef AFS_NT40_ENV
-#include <winsock2.h>
-#else
-#include <sys/socket.h>
-#include <netinet/in.h>
-#include <netdb.h>
-#endif
 #include <afs/com_err.h>
 #include <afs/bubasics.h>
 #include <lock.h>
 #include <afs/tcdata.h>
 #include <afs/cmd.h>
+
 #include "bc.h"
 #include "error_macros.h"
 #include "bucoord_internal.h"
@@ -75,32 +69,6 @@ nextItem(statusP linkPtr)
     return ((statusP) ptr);
 }
 
-#ifdef notdef
-static statusP
-nextItem(linkPtr)
-     statusP linkPtr;
-{
-    dlqlinkP ptr;
-
-    ptr = (dlqlinkP) linkPtr;
-
-    /* if last known item has terminated, reset ptr */
-    if (ptr == 0) {
-	ptr = &statusHead;
-	if (dlqEmpty(ptr))
-	    return (0);
-    }
-
-    ptr = ptr->dlq_next;
-
-    /* if we're back at the head again */
-    if (ptr == &statusHead) {
-	ptr = ptr->dlq_next;
-    }
-    return ((statusP) ptr);
-}
-#endif /* notdef */
-
 char *cmdLine;
 
 void *
@@ -394,7 +362,7 @@ statusWatcher(void *unused)
 	    curPollPtr = 0;
 	}			/*done */
     }				/*w */
-    return NULL;
+    AFS_UNREACHED(return(NULL));
 }
 
 /* bc_jobNumber
