@@ -97,6 +97,10 @@
 #define SYS_NAME_ID_x86_darwin_200       544
 #define SYS_NAME_ID_amd64_darwin_200     545
 #define SYS_NAME_ID_arm_darwin_200       546
+#define SYS_NAME_ID_amd64_darwin_210     547
+#define SYS_NAME_ID_arm_darwin_210       548
+#define SYS_NAME_ID_amd64_darwin_220     549
+#define SYS_NAME_ID_arm_darwin_220       550
 
 #define SYS_NAME_ID_next_mach20		 601
 #define SYS_NAME_ID_next_mach30		 602
@@ -109,6 +113,9 @@
 #define SYS_NAME_ID_rs_aix52		 706
 #define SYS_NAME_ID_rs_aix53		 707
 #define SYS_NAME_ID_rs_aix61		 708
+#define SYS_NAME_ID_rs_aix72		 709
+#define SYS_NAME_ID_rs_aix71		 710
+#define SYS_NAME_ID_rs_aix73		 711
 
 #define SYS_NAME_ID_sun3_411		 906
 #define SYS_NAME_ID_sun3x_411		 912
