@@ -17,7 +17,6 @@
 
 #define AFS_LINUX_ENV		1
 
-#define AFS_MOUNT_AFS		"afs"	/* The name of the filesystem type */
 #define AFS_64BIT_IOPS_ENV	1
 #define AFS_NAMEI_ENV		1	/* User space interface to file system */
 #define AFS_64BIT_CLIENT	1
@@ -37,9 +36,9 @@
 
 #define AFS_PRIVATE_OSI_ALLOCSPACES	1
 
-#if defined(__KERNEL__) && !defined(KDUMP_KERNEL)
+#if defined(__KERNEL__)
 #define AFS_GLOBAL_SUNLOCK
-#endif /* __KERNEL__	&& !DUMP_KERNEL */
+#endif /* __KERNEL__ */
 
 #ifdef KERNEL
 #ifndef MIN
@@ -68,7 +67,6 @@
 #define AFS_64BIT_CLIENT	1
 #undef  AFS_NONFSTRANS
 #define AFS_NONFSTRANS 		1
-#define AFS_MOUNT_AFS 		"afs"	/* The name of the filesystem type. */
 #define AFS_64BIT_IOPS_ENV	1
 #define AFS_NAMEI_ENV		1	/* User space interface to file system */
 #define AFS_USERSPACE_IP_ADDR 	1
