@@ -13,7 +13,6 @@
 #define AFS_XBSD_ENV		1	/* {Free,Open,Net}BSD */
 
 #define AFS_NAMEI_ENV		1	/* User space interface to file system */
-#define AFS_64BIT_ENV		1
 #define AFS_64BIT_CLIENT	1
 #define AFS_64BIT_IOPS_ENV	1	/* Needed for NAMEI */
 
@@ -27,14 +26,12 @@
 
 #undef  AFS_NONFSTRANS
 #define AFS_NONFSTRANS		1
-#define AFS_VM_RDWR_ENV		1
 #define AFS_VFS_ENV		1
 #define AFS_VFSINCL_ENV		1
 
 #define FTRUNC O_TRUNC
 
 #define AFS_SYSCALL		208
-#define AFS_MOUNT_AFS		"afs"
 
 #define RXK_LISTENER_ENV	1
 #define AFS_GCPAGS	        0	/* if nonzero, garbage collect PAGs */
@@ -49,7 +46,6 @@
 #ifdef MULTIPROCESSOR
 #define AFS_GLOBAL_SUNLOCK	1
 #endif
-#define	AFS_SHORTGID		0	/* are group id's short? */
 
 #if	!defined(ASSEMBLER) && !defined(__LANGUAGE_ASSEMBLY__)
 enum vcexcl { NONEXCL, EXCL };
