@@ -9,6 +9,7 @@
 
 #include <afsconfig.h>
 #include <afs/param.h>
+#include <afs/afsint.h>
 
 #ifdef KERNEL
 # if !defined(UKERNEL)
@@ -34,9 +35,9 @@
 #  if	defined(AFS_SUN5_ENV) || defined(AFS_HPUX_ENV) || defined(AFS_FBSD_ENV) || defined(AFS_DARWIN80_ENV)
 #   include "afs/sysincludes.h"
 #  endif
-#  if !defined(AFS_SGI64_ENV) && !defined(AFS_DARWIN_ENV) && !defined(AFS_OBSD48_ENV) && !defined(AFS_NBSD_ENV)
+#  if !defined(AFS_SGI_ENV) && !defined(AFS_DARWIN_ENV) && !defined(AFS_OBSD48_ENV) && !defined(AFS_NBSD_ENV)
 #   include "h/user.h"
-#  endif /* AFS_SGI64_ENV */
+#  endif /* AFS_SGI_ENV */
 #  include "h/uio.h"
 #  if !defined(AFS_SUN5_ENV) && !defined(AFS_LINUX_ENV) && !defined(AFS_HPUX110_ENV)
 #   include "h/mbuf.h"
@@ -47,6 +48,7 @@
 # else /* !defined(UKERNEL) */
 #  include "afs/stds.h"
 #  include "afs/sysincludes.h"
+#  include "afsincludes.h"
 # endif /* !defined(UKERNEL) */
 
 /* afs_buffer.c */
@@ -100,6 +102,7 @@ afs_dir_Create(dir_file_t dir, char *entry, void *voidfid)
     struct DirEntry *ep;
     struct DirHeader *dhp;
     int code;
+    size_t rlen;
 
     /* check name quality */
     if (*entry == 0)
@@ -129,7 +132,16 @@ afs_dir_Create(dir_file_t dir, char *entry, void *voidfid)
     ep->flag = FFIRST;
     ep->fid.vnode = htonl(vfid[1]);
     ep->fid.vunique = htonl(vfid[2]);
-    strcpy(ep->name, entry);
+
+    /*
+     * Note, the size of ep->name does not represent the maximum size of the
+     * name. FindBlobs has already ensured that the name can fit.
+     */
+    rlen = strlcpy(ep->name, entry, AFSNAMEMAX + 1);
+    if (rlen >= AFSNAMEMAX + 1) {
+	DRelease(&entrybuf, 1);
+	return ENAMETOOLONG;
+    }
 
     /* Now we just have to thread it on the hash table list. */
     if (DRead(dir, 0, &headerbuf) != 0) {
@@ -744,6 +756,7 @@ afs_dir_InverseLookup(void *dir, afs_uint32 vnode, afs_uint32 unique,
     struct DirBuffer entrybuf;
     struct DirEntry *entry;
     int code = 0;
+    size_t rlen;
 
     code = FindFid(dir, vnode, unique, &entrybuf);
     if (code) {
@@ -751,10 +764,10 @@ afs_dir_InverseLookup(void *dir, afs_uint32 vnode, afs_uint32 unique,
     }
     entry = (struct DirEntry *)entrybuf.data;
 
-    if (strlen(entry->name) >= length)
+    rlen = strlcpy(name, entry->name, length);
+    if (rlen >= length) {
 	code = E2BIG;
-    else
-	strcpy(name, entry->name);
+    }
     DRelease(&entrybuf, 0);
     return code;
 }
