@@ -10,11 +10,8 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
+#include <roken.h>
 
-#include <string.h>
-#ifdef HAVE_STDINT_H
-#include <stdint.h>
-#endif
 #include "gtxwindows.h"
 #include "gtxobjects.h"
 #include "gtxtextobj.h"
@@ -48,7 +45,7 @@ ChangeMenuCmd(void *param1, void *param2)
 	if (code)
 	    gtxframe_DisplayString(tf, "Can't delete menu!");
     } else if (arock == 3) {
-	code = gtxframe_ClearMenus(tf);
+	gtxframe_ClearMenus(tf);
 	gtxframe_AddMenu(frameA, "FrameB", "b");
 	gtxframe_AddMenu(frameA, "NewLabel", "c");
     }
@@ -75,7 +72,7 @@ ChangeListCmd(void *param1, void *param2)
 	if (code)
 	    gtxframe_DisplayString(tf, "Can't delete light!");
     } else if (arock == 3) {
-	code = gtxframe_ClearList(tf);
+	gtxframe_ClearList(tf);
 	gtxframe_AddToList(frameA, objectA);
 	gtxframe_AddToList(frameA, lightA);
     }
@@ -237,7 +234,7 @@ main(int argc, char **argv)
     keymap_BindToString(frameB->keymap, "a", SwitchToACmd, NULL, NULL);
     keymap_BindToString(frameB->keymap, "b", StupidCmd, NULL, NULL);
     keymap_BindToString(frameB->keymap, "d", NoCallCmd, NULL, NULL);
-    keymap_BindToString(frameB->keymap, "d", (int (*)())0, NULL, NULL);
+    keymap_BindToString(frameB->keymap, "d", NULL, NULL, NULL);
     keymap_BindToString(frameB->keymap, "\033d", NoCallCmd, NULL, NULL);
     gtxframe_AddMenu(frameB, "FrameA", "a");
 
