@@ -7,10 +7,11 @@
  * directory or online at http://www.openafs.org/dl/license10.html
  */
 
-
 #include <afsconfig.h>
 #include <afs/param.h>
+#include <afs/stds.h>
 
+#include <roken.h>
 
 /*
  *                      (3) Define a structure, idused, instead of an
@@ -30,21 +31,13 @@
  *                          conditions.
  */
 
-#include <afs/stds.h>
-#include <sys/types.h>
+
 #ifdef AFS_NT40_ENV
-#include <winsock2.h>
 #include <WINNT/afsevent.h>
-#include <io.h>
 #else
-#include <netdb.h>
-#include <netinet/in.h>
 #include <sys/file.h>
 #endif
-#include <stdio.h>
-#include <string.h>
-#include <errno.h>
-#include <fcntl.h>
+
 #include <afs/cellconfig.h>
 #include <afs/afsutil.h>
 #include <ubik.h>
@@ -267,6 +260,13 @@ PrintEntryError(struct misc_data *misc, afs_int32 ea, struct prentry *e, int ind
     return 0;
 }
 
+int
+PrintContError(struct misc_data *misc, afs_int32 ea, struct contentry *c, int indent)
+{
+    pr_PrintContEntry(stderr, /*net order */ 0, ea, c, indent);
+    return 0;
+}
+
 afs_int32
 WalkHashTable(afs_int32 hashtable[],	/* hash table to walk */
 	      int hashType,		/* hash function to use */
@@ -392,7 +392,7 @@ WalkNextChain(char map[],		/* one byte per db entry */
     afs_int32 head;
     int bit;
     afs_int32 code;
-    struct prentry c;		/* continuation entry */
+    struct contentry c;		/* continuation entry */
     afs_int32 na;		/* next thread */
     int ni;
     afs_int32 eid = 0;
@@ -500,7 +500,7 @@ WalkNextChain(char map[],		/* one byte per db entry */
 		return PRDBBAD;
 	    if (na != sghead) {
 		fprintf(stderr, "last block: \n");
-		if (PrintEntryError(misc, na, &c, 4))
+		if (PrintContError(misc, na, &c, 4))
 		    return PRDBBAD;
 	    }
 	    return 0;
@@ -514,7 +514,7 @@ WalkNextChain(char map[],		/* one byte per db entry */
 	    fprintf(stderr, "Continuation entry reused\n");
 	    if (PrintEntryError(misc, ea, e, 2))
 		return PRDBBAD;
-	    if (PrintEntryError(misc, na, &c, 4))
+	    if (PrintContError(misc, na, &c, 4))
 		return PRDBBAD;
 	    noErrors = 0;
 	    break;
@@ -524,7 +524,7 @@ WalkNextChain(char map[],		/* one byte per db entry */
 	    fprintf(stderr, "Continuation id mismatch\n");
 	    if (PrintEntryError(misc, ea, e, 2))
 		return PRDBBAD;
-	    if (PrintEntryError(misc, na, &c, 4))
+	    if (PrintContError(misc, na, &c, 4))
 		return PRDBBAD;
 	    noErrors = 0;
 	    continue;
@@ -548,7 +548,7 @@ WalkNextChain(char map[],		/* one byte per db entry */
 			    "User can't be member of supergroup list\n");
 		    if (PrintEntryError(misc, ea, e, 2))
 			return PRDBBAD;
-		    if (PrintEntryError(misc, na, &c, 4))
+		    if (PrintContError(misc, na, &c, 4))
 			return PRDBBAD;
 		    noErrors = 0;
 		}
@@ -575,7 +575,7 @@ WalkNextChain(char map[],		/* one byte per db entry */
 		return PRDBBAD;
 	    if (na != head) {
 		fprintf(stderr, "last block: \n");
-		if (PrintEntryError(misc, na, &c, 4))
+		if (PrintContError(misc, na, &c, 4))
 		    return PRDBBAD;
 	    }
 	    return 0;
@@ -591,7 +591,7 @@ WalkNextChain(char map[],		/* one byte per db entry */
 		fprintf(stderr, "walking free list");
 	    else if (PrintEntryError(misc, ea, e, 2))
 		return PRDBBAD;
-	    if (PrintEntryError(misc, na, &c, 4))
+	    if (PrintContError(misc, na, &c, 4))
 		return PRDBBAD;
 	    noErrors = 0;
 	    break;
@@ -603,7 +603,7 @@ WalkNextChain(char map[],		/* one byte per db entry */
 		fprintf(stderr, "walking free list");
 	    else if (PrintEntryError(misc, ea, e, 2))
 		return PRDBBAD;
-	    if (PrintEntryError(misc, na, &c, 4))
+	    if (PrintContError(misc, na, &c, 4))
 		return PRDBBAD;
 	    noErrors = 0;
 	    continue;
@@ -633,7 +633,7 @@ WalkNextChain(char map[],		/* one byte per db entry */
 				"User can't be member of user in membership list\n");
 			if (PrintEntryError(misc, ea, e, 2))
 			    return PRDBBAD;
-			if (PrintEntryError(misc, na, &c, 4))
+			if (PrintContError(misc, na, &c, 4))
 			    return PRDBBAD;
 			noErrors = 0;
 		    }
@@ -643,7 +643,7 @@ WalkNextChain(char map[],		/* one byte per db entry */
 				"Bad user/group dicotomy in membership list\n");
 			if (PrintEntryError(misc, ea, e, 2))
 			    return PRDBBAD;
-			if (PrintEntryError(misc, na, &c, 4))
+			if (PrintContError(misc, na, &c, 4))
 			    return PRDBBAD;
 			noErrors = 0;
 		    }
@@ -705,7 +705,7 @@ WalkOwnedChain(char map[],		/* one byte per db entry */
 {
     afs_int32 head;
     afs_int32 code;
-    struct prentry c;		/* continuation entry */
+    struct prentry te;		/* next entry in owner chain */
     afs_int32 na;		/* next thread */
     int ni;
     afs_int32 eid = 0;
@@ -718,7 +718,7 @@ WalkOwnedChain(char map[],		/* one byte per db entry */
 	head = ntohl(cheader.orphan);
 
     length = 0;
-    for (na = head; na; na = ntohl(c.nextOwned)) {
+    for (na = head; na; na = ntohl(te.nextOwned)) {
 	code = ConvertDiskAddress(na, &ni);
 	if (code) {
 	    fprintf(stderr, "Bad owned list ptr %d", na);
@@ -728,23 +728,33 @@ WalkOwnedChain(char map[],		/* one byte per db entry */
 		return PRDBBAD;
 	    if (na != head) {
 		fprintf(stderr, "last block: \n");
-		if (PrintEntryError(misc, na, &c, 4))
+		if (PrintEntryError(misc, na, &te, 4))
 		    return PRDBBAD;
 	    }
 	    return 0;
 	}
-	code = pr_Read(na, (char *)&c, sizeof(c));
+	code = pr_Read(na, (char *)&te, sizeof(te));
 	if (code)
 	    return code;
 	length++;
 
+	if ((ntohl(te.flags) & PRTYPE) == PRCONT) {
+	    fprintf(stderr, "Continuation entry found on owner chain\n");
+	    if (e == 0)
+		fprintf(stderr, "walking orphan list");
+	    else if (PrintEntryError(misc, ea, e, 2))
+		return PRDBBAD;
+	    if (PrintEntryError(misc, na, &te, 4))
+		return PRDBBAD;
+	    break;
+	}
 	if (map[ni] & MAP_OWNED) {
 	    fprintf(stderr, "Entry on multiple owner chains\n");
 	    if (e == 0)
 		fprintf(stderr, "walking orphan list");
 	    else if (PrintEntryError(misc, ea, e, 2))
 		return PRDBBAD;
-	    if (PrintEntryError(misc, na, &c, 4))
+	    if (PrintEntryError(misc, na, &te, 4))
 		return PRDBBAD;
 	    break;
 	}
@@ -756,16 +766,16 @@ WalkOwnedChain(char map[],		/* one byte per db entry */
 		fprintf(stderr, "walking orphan list");
 	    else if (PrintEntryError(misc, ea, e, 2))
 		return PRDBBAD;
-	    if (PrintEntryError(misc, na, &c, 4))
+	    if (PrintEntryError(misc, na, &te, 4))
 		return PRDBBAD;
 	    continue;
 	}
 	if (e) {
-	    if (ntohl(c.owner) != eid) {
+	    if (ntohl(te.owner) != eid) {
 		fprintf(stderr, "Owner id mismatch\n");
 		goto abort;
 	    }
-	} else /* orphan */ if (c.owner) {
+	} else /* orphan */ if (te.owner) {
 	    fprintf(stderr, "Orphan group owner not zero\n");
 	    goto abort;
 	}
@@ -965,10 +975,8 @@ QuoteName(char *s)
 {
     char *qs;
     if (strpbrk(s, " \t")) {
-	qs = (char *)malloc(strlen(s) + 3);
-	strcpy(qs, "\"");
-	strcat(qs, s);
-	strcat(qs, "\"");
+	if (asprintf(&qs, "\"%s\"", s) < 0)
+	    qs = "<<-OUT-OF-MEMORY->>";
     } else
 	qs = s;
     return qs;
@@ -985,7 +993,6 @@ DumpRecreate(char map[], struct misc_data *misc)
     afs_int32 flags;
     afs_int32 owner;
     char *name;
-    int builtinUsers = 0;
     int createLow = 0;		/* users uncreate from here */
 #if defined(SUPERGROUPS)
     struct idused *idmap;	/* map of all id's */
@@ -1028,10 +1035,8 @@ DumpRecreate(char map[], struct misc_data *misc)
 		    || !strcmp(e.name, "system:anyuser")
 		    || !strcmp(e.name, "system:authuser")
 		    || !strcmp(e.name, "system:backup")
-		    || !strcmp(e.name, "anonymous")) {
-		    builtinUsers++;
+		    || !strcmp(e.name, "anonymous"))
 		    goto user_done;
-		}
 
 		/* check for duplicate id.  This may still lead to duplicate
 		 * names. */
@@ -1196,7 +1201,7 @@ DumpRecreate(char map[], struct misc_data *misc)
 		}
 		na = ntohl(e.next);
 		while (na) {
-		    struct prentry c;
+		    struct contentry c;
 		    code = pr_Read(na, (char *)&c, sizeof(c));
 		    if (code)
 			return code;
@@ -1259,8 +1264,7 @@ CheckPrDatabase(struct misc_data *misc)	/* info & statistics */
     }
     if (misc->verbose)
 	printf("Database has %d entries\n", n);
-    map = (char *)malloc(n);
-    memset(map, 0, n);
+    map = calloc(1, n);
     misc->nEntries = n;
 
     if (misc->verbose) {
@@ -1288,14 +1292,13 @@ CheckPrDatabase(struct misc_data *misc)	/* info & statistics */
 #else
     n = ((misc->maxId > misc->maxForId) ? misc->maxId : misc->maxForId);
     misc->idRange = n - misc->minId + 1;
-    misc->idmap = (afs_int32 *) malloc(misc->idRange * sizeof(afs_int32));
+    misc->idmap = calloc(misc->idRange, sizeof(afs_int32));
     if (!misc->idmap) {
 	afs_com_err(whoami, 0, "Unable to malloc space for max ids of %d",
 		misc->idRange);
 	code = -1;
 	goto abort;
     }
-    memset(misc->idmap, 0, misc->idRange * sizeof(misc->idmap[0]));
 #endif /* SUPERGROUPS */
 
     if (misc->verbose) {
@@ -1443,7 +1446,7 @@ main(int argc, char *argv[])
 
     setlinebuf(stdout);
 
-    ts = cmd_CreateSyntax(NULL, WorkerBee, NULL, "PRDB check");
+    ts = cmd_CreateSyntax(NULL, WorkerBee, NULL, 0, "PRDB check");
     cmd_AddParm(ts, "-database", CMD_SINGLE, CMD_REQUIRED, "ptdb_file");
     cmd_AddParm(ts, "-uheader", CMD_FLAG, CMD_OPTIONAL,
 		"Display UBIK header");
