@@ -42,12 +42,12 @@
 #else /* AFS_NT40_ENV */
 # if !defined(AFS_DARWIN_ENV) && !defined(AFS_USR_DARWIN_ENV)   \
     && !defined(AFS_XBSD_ENV) && !defined(AFS_USR_FBSD_ENV)     \
-    && !defined(AFS_USR_DFBSD_ENV) && !defined(AFS_LINUX20_ENV)
+    && !defined(AFS_USR_DFBSD_ENV) && !defined(AFS_LINUX_ENV)
 #  include <sys/sysmacros.h>	/* MIN, MAX on most commercial UNIX */
 # endif
 /* Linux 3.7 doesn't have sys/param.h in kernel space, and afs/param.h ensures
  * that MIN and MAX are available for kernel builds. */
-# if !(defined(AFS_LINUX26_ENV) && defined(KERNEL))
+# if !(defined(AFS_LINUX_ENV) && defined(KERNEL))
 #  include <sys/param.h>	/* MIN, MAX elsewhere */
 # endif
 #endif /* !AFS_NT40_ENV */
@@ -72,7 +72,6 @@
  * the MAX packet size will be the maximum receive size, but the maximum send
  * size will be larger than that. */
 
-#ifdef notdef
 /*  some sample MTUs
            4352   what FDDI(RFC1188) uses... Larger?
            4096   VJ's recommendation for FDDI
@@ -85,23 +84,6 @@
 	   9180   Classical IP over ATM (RFC2225)
 */
 
-/* * * * these are the old defines
-*/
-#define	RX_MAX_PACKET_SIZE	(RX_MAX_DL_MTU -RX_IPUDP_SIZE)
-
-#define	RX_MAX_PACKET_DATA_SIZE	(RX_MAX_PACKET_SIZE-RX_HEADER_SIZE)
-#ifdef AFS_HPUX_ENV
-/* HPUX by default uses an 802.3 size, and it's not evident from SIOCGIFCONF */
-#define	RX_LOCAL_PACKET_SIZE	(1492 - RX_IPUDP_SIZE)
-#define	RX_REMOTE_PACKET_SIZE	(1492 - RX_IPUDP_SIZE)
-#else
-#define	RX_LOCAL_PACKET_SIZE	RX_MAX_PACKET_SIZE	/* For hosts on same net */
-#define	RX_REMOTE_PACKET_SIZE	RX_MAX_PACKET_SIZE	/* see note above */
-#endif
-#endif /* notdef */
-
-/* These are the new, streamlined ones.
- */
 #define	RX_HEADER_SIZE		sizeof (struct rx_header)
 
 /* The minimum MTU for an IP network is 576 bytes including headers */
